import numpy as np

from scipy.integrate import ode
from numpy import linalg as LA

def cannon_hit_fun(alpha):
            
    # given data
    v0 = 100
    g = 10
    m = 20
    rho = 0.1
    
    #define right hand side
    def rhs(t,y):
        return np.array([y[2], y[3], -rho/m*LA.norm(y[2:4])*y[2], -g-rho/m*LA.norm(y[2:4])*y[3]])    
    
    # specify integration interval
    t0=0;
    t1=100;
    t = np.linspace(t0, t1, 10000)
    
    # determine initial conditions
    y0=np.array([0,0,v0*np.cos(alpha),v0*np.sin(alpha)])
    
    #Create empty solution vector
    y = np.zeros((len(t), len(y0)))
    y[0, :] = y0
    
    #carry out integration using integrate from ode 
    r=ode(rhs)
    r.set_initial_value(y0, t0)
    
    for i in range(1, t.size):
        y[i, :] = r.integrate(t[i])
        
    x1=0
    
    #return point of impact
    for i in range(1, t.size-1):
        if y[i,1]>=0 and y[i+1,1]<=0:
            x1=y[i+1,0]
    return x1        

